@@ -21,9 +21,7 @@ sub post_transaction {
   my $disconnect = ($dbh) ? 0 : 1;
   
   # connect to database
-  if (! $dbh) {
-    $dbh = $form->dbconnect_noauto($myconfig);
-  }
+  $dbh = $form->dbconnect_noauto($myconfig) unless $dbh;
 
   my $query;
   my $sth;
@@ -254,6 +252,10 @@ sub post_transaction {
 
 
   $form->{amount} = $invamount;          # need for vr batch
+  
+  ($paymentaccno) = split /--/, $form->{"$form->{ARAP}_paid_$form->{paidaccounts}"};
+  ($null, $paymentmethod_id) = split /--/, $form->{"paymentmethod_$form->{paidaccounts}"};
+  $paymentmethod_id *= 1;
 
   if ($form->{vc} eq 'customer') {
     # dcn
@@ -269,10 +271,6 @@ sub post_transaction {
     for my $dcn (qw(dcn rvc)) { $form->{$dcn} = $form->format_dcn($form->{$dcn}) }
   }
 
-  ($paymentaccno) = split /--/, $form->{"$form->{ARAP}_paid_$form->{paidaccounts}"};
-  ($null, $paymentmethod_id) = split /--/, $form->{"paymentmethod_$form->{paidaccounts}"};
-  $paymentmethod_id *= 1;
-
 
   $query = qq|UPDATE $table SET
 	      invnumber = |.$dbh->quote($form->{invnumber}).qq|,
@@ -1107,7 +1105,7 @@ sub get_name {
   $form->{currency} = ($form->{currency}) ? $form->{currency} : $form->{defaultcurrency};
   delete $form->{exchangerate};
   if ($form->{transdate} && ($form->{currency} ne $form->{defaultcurrency})) {
-    $form->{exchangerate} = $form->get_exchangerate($dbh, $form->{currency}, $form->{transdate}, $buysell);
+    $form->{exchangerate} = $form->get_exchangerate($myconfig, $dbh, $form->{currency}, $form->{transdate}, $buysell);
   }
   
   # if no employee, default to login
@@ -1255,10 +1253,12 @@ sub get_name {
 
 ############# add addressid, contactid for multiple addresses and contacts
 sub company_details {
-  my ($self, $myconfig, $form) = @_;
+  my ($self, $myconfig, $form, $dbh) = @_;
 
+  my $disconnect = ($dbh) ? 0 : 1;
+  
   # connect to database
-  my $dbh = $form->dbconnect($myconfig);
+  $dbh = $form->dbconnect($myconfig) unless $dbh;
   
   # get rest for the customer/vendor
   my $query = qq|SELECT ct.$form->{vc}number, ct.name, ad.address1, ad.address2,
@@ -1330,6 +1330,68 @@ sub company_details {
     for (qw(iban bic membernumber rvc dcn)) { $form->{$_} = $form->{"bank$_"} };
   }
 
+  $dbh->disconnect if $disconnect;
+
+}
+
+
+sub ship_to {
+  my ($self, $myconfig, $form) = @_;
+
+  # connect to database
+  my $dbh = $form->dbconnect($myconfig);
+
+  AA->company_details($myconfig, $form, $dbh);
+
+  my $table = ($form->{vc} eq 'customer') ? 'ar' : 'ap';
+
+  my $query = qq|SELECT
+                 s.shiptoname, s.shiptoaddress1, s.shiptoaddress2,
+		 s.shiptocity, s.shiptostate, s.shiptozipcode,
+		 s.shiptocountry, s.shiptocontact, s.shiptophone,
+		 s.shiptofax, s.shiptoemail
+		 FROM shipto s
+		 WHERE trans_id = $form->{"$form->{vc}_id"}
+		 UNION
+		 SELECT
+		 s.shiptoname, s.shiptoaddress1, s.shiptoaddress2,
+		 s.shiptocity, s.shiptostate, s.shiptozipcode,
+		 s.shiptocountry, s.shiptocontact, s.shiptophone,
+		 s.shiptofax, s.shiptoemail
+		 FROM shipto s
+		 JOIN oe o ON (o.id = s.trans_id)
+		 WHERE o.$form->{vc}_id = $form->{"$form->{vc}_id"}
+		 UNION
+		 SELECT
+		 s.shiptoname, s.shiptoaddress1, s.shiptoaddress2,
+		 s.shiptocity, s.shiptostate, s.shiptozipcode,
+		 s.shiptocountry, s.shiptocontact, s.shiptophone,
+		 s.shiptofax, s.shiptoemail
+		 FROM shipto s
+		 JOIN $table a ON (a.id = s.trans_id)
+		 WHERE a.$form->{vc}_id = $form->{"$form->{vc}_id"}|;
+
+  if ($form->{id}) {
+    $query .= qq|
+                 EXCEPT
+		 SELECT
+		 s.shiptoname, s.shiptoaddress1, s.shiptoaddress2,
+		 s.shiptocity, s.shiptostate, s.shiptozipcode,
+		 s.shiptocountry, s.shiptocontact, s.shiptophone,
+		 s.shiptofax, s.shiptoemail
+		 FROM shipto s
+		 WHERE s.trans_id = '$form->{id}'|;
+  }
+
+  my $sth = $dbh->prepare($query);
+  $sth->execute || $form->dberror($query);
+  
+  my $ref;
+  while ($ref = $sth->fetchrow_hashref(NAME_lc)) {
+    push @{ $form->{all_shipto} }, $ref;
+  }
+  $sth->finish;
+
   $dbh->disconnect;
 
 }
