@@ -77,6 +77,7 @@ sub edit {
     $form->{vc} = 'customer';
   }
 
+  $form->{shipto} = 1;
   &order_links;
   &prepare_order;
   &display_form;
@@ -131,7 +132,6 @@ sub order_links {
   }
   
   for (qw(terms taxincluded)) { $temp{$_} = $form->{$_} }
-  $form->{shipto} = 1 if $form->{id};
 
   # get customer / vendor
   AA->get_name(\%myconfig, \%$form);
@@ -298,6 +298,21 @@ sub prepare_order {
 }
 
 
+sub lookup_order {
+
+  $form->isblank("ordnumber", $locale->text('Order Number missing!'));
+
+  if ($id = OE->lookup_order(\%myconfig, \%$form)) {
+    $type = ($form->{vc} eq 'customer') ? 'sales_order' : 'purchase_order';
+    $form->{callback} = "oe.pl?action=edit&id=$id&type=$type&vc=$form->{vc}&path=$form->{path}&login=$form->{login}";
+    $form->redirect;
+  } else {
+    $form->error($locale->text('Order not on file!'));
+  }
+
+}
+
+
 sub form_header {
 
   $checkedopen = ($form->{closed}) ? "" : "checked";
@@ -618,7 +633,7 @@ sub form_header {
   </tr>
 |;
 
-  $form->hide_form(qw(shiptoname shiptoaddress1 shiptoaddress2 shiptocity shiptostate shiptozipcode shiptocountry shiptocontact shiptophone shiptofax shiptoemail message email subject cc bcc taxaccounts));
+  $form->hide_form(qw(shiptoname shiptoaddress1 shiptoaddress2 shiptocity shiptostate shiptozipcode shiptocountry shiptocontact shiptophone shiptofax shiptoemail message email subject cc bcc taxaccounts aa_id));
 
   foreach $accno (split / /, $form->{taxaccounts}) { $form->hide_form(map { "${accno}_$_" } qw(rate description taxnumber)) }
 
@@ -818,6 +833,10 @@ sub form_footer {
 	  }
 	}
       }
+
+      if ($form->{aa_id}) {
+	for ("Update", "Save", "Ship to", "Ship all", "Print and Save", "Sales Invoice", "Vendor Invoice", "Delete") { delete $a{$_} }
+      }
     }
 
     if ($form->{type} =~ /_order/) {
@@ -1095,6 +1114,13 @@ sub search {
     $ordlabel = $locale->text('Order Number');
     $ordnumber = 'ordnumber';
     $employee = $locale->text('Salesperson');
+    $detail = qq|
+                <tr>
+		  <td><input name=detail type=radio class=radio value=0 checked> |.$locale->text('Summary').qq|</td>
+		  <td><input name=detail type=radio class=radio value=1> |.$locale->text('Detail').qq|
+		  </td>
+		</tr>
+|;
   }
   
   if ($form->{type} eq 'consolidate_purchase_order') {
@@ -1340,6 +1366,7 @@ sub search {
           <td colspan=3>
 	    <table>
 	      $openclosed
+	      $detail
 |;
 
   while (@a) {
@@ -1536,6 +1563,7 @@ sub transactions {
   unshift @columns, "runningnumber";
 
   $form->{l_open} = $form->{l_closed} = "Y" if ($form->{open} && $form->{closed}) ;
+  $form->{l_memo} = "Y" if $form->{detail};
 
   for (@columns) {
     if ($form->{"l_$_"} eq "Y") {
@@ -1626,6 +1654,7 @@ sub transactions {
 	$button{'Order Entry--Purchase Order'}{code} = qq|<input class=submit type=submit name=action value="|.$locale->text('Generate Purchase Orders').qq|"> |;
 	$button{'Order Entry--Purchase Order'}{order} = $i++;
       }
+      $callback .= "&detail=$form->{detail}";
     }
     if ($form->{type} eq 'consolidate_sales_order') {
       $form->{title} = $locale->text('Sales Orders');
@@ -1796,7 +1825,9 @@ function CheckAll() {
     $column_data{reqdate} = "<td nowrap>$ref->{reqdate}&nbsp;</td>";
 
     $column_data{runningnumber} = qq|<td align=right>$i</td>|;
-    $column_data{ndx} = qq|<td><input name="ndx_$i" class=checkbox type=checkbox value=$ref->{id} checked></td>|;
+    $id = ($ref->{orderitemsid}) ? "$ref->{id}--$ref->{orderitemsid}" : $ref->{id};
+    
+    $column_data{ndx} = qq|<td><input name="ndx_$i" class=checkbox type=checkbox value=$id checked></td>|;
     $column_data{$ordnumber} = "<td><a href=$form->{script}?path=$form->{path}&action=$action&type=$form->{type}&id=$ref->{id}&warehouse=$warehouse&vc=$form->{vc}&login=$form->{login}&callback=$callback>$ref->{$ordnumber}</a></td>";
 
     $name = $form->escape($ref->{name});
@@ -1865,7 +1896,7 @@ function CheckAll() {
 <br>
 |;
 
-  $form->hide_form(qw(callback type vc path login department ordnumber ponumber));
+  $form->hide_form(qw(callback type vc path login department ordnumber ponumber detail));
   
   print qq|
 
@@ -2230,7 +2261,7 @@ sub create_backorder {
     return;
   }
 
-  @flds = qw(partnumber description lineitemdetail qty ship unit sellprice discount oldqty oldship orderitems_id id bin weight listprice lastcost taxaccounts pricematrix sku onhand bin assembly inventory_accno_id income_accno_id expense_accno_id deliverydate reqdate itemnotes serialnumber projectnumber package netweight grossweight volume partsgroup);
+  @flds = qw(partnumber description lineitemdetail qty ship unit sellprice discount oldqty oldship orderitems_id id bin weight listprice lastcost taxaccounts pricematrix sku onhand bin assembly inventory_accno_id income_accno_id expense_accno_id deliverydate reqdate itemnotes serialnumber ordernumber customerponumber projectnumber package netweight grossweight volume partsgroup);
 
   for $i (1 .. $form->{rowcount}) {
     for (qw(qty sellprice discount)) { $form->{"${_}_$i"} = $form->format_amount(\%myconfig, $form->{"${_}_$i"}) }
@@ -2545,7 +2576,7 @@ sub display_ship_receive {
     print qq|
         </tr>
 |;
-    $form->hide_form(map { "${_}_$i"} qw(partnumber description sku orderitems_id id partsgroup unit bin qty));
+    $form->hide_form(map { "${_}_$i"} qw(partnumber description itemnotes lineitemdetail sku orderitems_id id partsgroup unit bin qty));
 
     if ($form->{type} eq 'ship_order') {
       print qq|
@@ -2702,7 +2733,7 @@ sub generate_purchase_orders {
 
     $form->{"lastcost_$i"} = $form->format_amount(\%myconfig, $form->{orderitems}{$parts_id}{lastcost}, $form->{precision});
 
-    $form->{"qty_$i"} = $required;
+    $form->{"qty_$i"} = $form->format_amount(\%myconfig, $required);
     
     if (exists $form->{orderitems}{$parts_id}{"parts$form->{vc}"}) {
       $form->{"qty_$i"} = "";
@@ -2832,7 +2863,7 @@ BLANKROW:
 <br>
 |;
 
-  $form->hide_form(qw(callback department ponumber path login employee_id vc nextsub rowcount type));
+  $form->hide_form(qw(callback department ponumber path login employee_id vc nextsub rowcount type detail));
   
   print qq|
 <input class=submit type=submit name=action value="|.$locale->text('Generate Orders').qq|">|;
