@@ -37,6 +37,7 @@ sub add {
 
 sub edit {
   
+  $form->{shipto} = 1;
   &invoice_links;
   &prepare_invoice;
   &display_form;
@@ -159,6 +160,7 @@ sub invoice_links {
 	# reverse paid
 	$form->{"paid_$i"} = $form->{acc_trans}{$key}->[$i-1]->{amount} * -1 * $ml;
 	$form->{"datepaid_$i"} = $form->{acc_trans}{$key}->[$i-1]->{transdate};
+	$form->{"olddatepaid_$i"} = $form->{acc_trans}{$key}->[$i-1]->{transdate};
 	$form->{"exchangerate_$i"} = $form->{acc_trans}{$key}->[$i-1]->{exchangerate};
 	$form->{"source_$i"} = $form->{acc_trans}{$key}->[$i-1]->{source};
 	$form->{"memo_$i"} = $form->{acc_trans}{$key}->[$i-1]->{memo};
@@ -173,6 +175,7 @@ sub invoice_links {
       $form->{"AR_discount_paid"} = "$form->{acc_trans}{$key}->[0]->{accno}--$form->{acc_trans}{$key}->[0]->{description}";
       $form->{"discount_paid"} = $form->{acc_trans}{$key}->[0]->{amount} * -1 * $ml;
       $form->{"discount_datepaid"} = $form->{acc_trans}{$key}->[0]->{transdate};
+      $form->{"olddiscount_datepaid"} = $form->{acc_trans}{$key}->[0]->{transdate};
       $form->{"discount_source"} = $form->{acc_trans}{$key}->[0]->{source};
       $form->{"discount_memo"} = $form->{acc_trans}{$key}->[0]->{memo};
       $form->{"discount_exchangerate"} = $form->{acc_trans}{$key}->[0]->{exchangerate};
@@ -328,7 +331,7 @@ sub form_header {
                 <td colspan=3><select name="$form->{vc}" onChange="javascript:document.forms[0].submit()">|.$form->select_option($form->{"select$form->{vc}"}, $form->{$form->{vc}}, 1).qq|</select>
 		</td>
 	      </tr>
-|;
+| . $form->hide_form("$form->{vc}number");
   } else {
     $vc .= qq|
                 <td colspan=3><input name="$form->{vc}" value="|.$form->quote($form->{$form->{vc}}).qq|" size=35>
@@ -865,7 +868,8 @@ sub form_footer {
 	       'Print and Post as new' => { ndx => 8, key => 'W', value => $locale->text('Print and Post as new') },
 	       'Sales Order' => { ndx => 9, key => 'L', value => $locale->text('Sales Order') },
 	       'Schedule' => { ndx => 10, key => 'H', value => $locale->text('Schedule') },
-	       'Delete' => { ndx => 11, key => 'D', value => $locale->text('Delete') },
+	       'New Number' => { ndx => 13, key => 'M', value => $locale->text('New Number') },
+	       'Delete' => { ndx => 14, key => 'D', value => $locale->text('Delete') },
 	      );
 
     if ($form->{id}) {
@@ -884,7 +888,7 @@ sub form_footer {
 
       if ($transdate > $form->{closedto}) {
 	
-	for ("Update", "Ship to", "Print", "E-mail", "Post", "Schedule") { $a{$_} = 1 }
+	for ("Update", "New Number", "Ship to", "Print", "E-mail", "Post", "Schedule") { $a{$_} = 1 }
 	$a{'Print and Post'} = 1 if $latex;
 	
       }
